## cdist-type__install_reboot(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__install_reboot - run reboot

## 2. DESCRIPTION

This cdist type allows you to reboot a machine.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

options
  options to pass to the reboot command. e.g. -f

## 5. EXAMPLES

    __install_reboot

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).